@@ -1,5 +1,5 @@
 import numpy as np
-import gdal
+from osgeo import gdal
 import pywapor.general.processing_functions as PF
 import warnings
 import os
@@ -470,7 +470,7 @@ def plot_composite(ds, diagnostics, out_folder = None, band_name = "band_data"):
         ndvis = ts[band_name].values
         sources = ts.sources.values
 
-        ndvi_composites = ts.composite.values
+        ndvi_composites = ts[f"{band_name}_composite"].values
         epoch_starts = ts.epoch_starts.values
         epoch_ends = ts.epoch_ends.values
 
